@@ -4,7 +4,7 @@ from WebKit import *
 
 class TestDOMElement (TestCase):
     def testConstants(self):
-        self.assertEquals(DOM_ALLOW_KEYBOARD_INPUT, 1)
+        self.assertEqual(DOM_ALLOW_KEYBOARD_INPUT, 1)
 
     def testMethods(self):
         self.assertResultIsBOOL(DOMElement.hasAttribute_)
