@@ -6,7 +6,7 @@ class TestWebPluginHelper (NSObject):
     def webPlugInSetIsSelected_(self, v): pass
 
 class TestWebPlugin (TestCase):
-    def testConstants(self):
+    def testMethods(self):
         self.assertArgIsBOOL(TestWebPluginHelper.webPlugInSetIsSelected_, 0)
 
 if __name__ == "__main__":
